## 财经日历

接口：eco_cal

描述：获取全球财经日历、包括经济事件数据更新

限量：单次最大获取100行数据

积分：2000积分可调取

输入参数

| 名称 | 类型 | 必选 | 描述 |
| --- | --- | --- | --- |
| date | str | N | 日期（YYYYMMDD格式） |
| start_date | str | N | 开始日期 |
| end_date | str | N | 结束日期 |
| currency | str | N | 货币代码 |
| country | str | N | 国家（比如：中国、美国） |
| event | str | N | 事件 （支持模糊匹配： *非农*） |

输出参数

| 名称 | 类型 | 默认显示 | 描述 |
| --- | --- | --- | --- |
| date | str | Y | 日期 |
| time | str | Y | 时间 |
| currency | str | Y | 货币代码 |
| country | str | Y | 国家 |
| event | str | Y | 经济事件 |
| value | str | Y | 今值 |
| pre_value | str | Y | 前值 |
| fore_value | str | Y | 预测值 |

接口示例

```python
pro = ts.pro_api()


#获取指定日期全球经济日历
df = pro.eco_cal(date='20200403')


#获取中国经济事件
df = pro.eco_cal(country='中国')

#获取美国非农数据
df = pro.eco_cal(event='美国季调后非农*', fields='date,time,country,event,value,pre_value,fore_value')
```

数据示例

```python
date      time    country                   event         value pre_value fore_value
0   20200410  09:30      中国      中国PPI年率(%)(年度)(三月)           -0.4%      -1.1%
```

美国非农数据：

```python
date       time   country              event                 value pre_value fore_value
0   20200403  20:30      美国  美国季调后非农就业人口变动(三月)  -701K      275K      -100K
1   20200403  20:30      美国  美国季调后非农就业人口变动(三月)             273K      -100K
2   20200403  20:30      美国  美国季调后非农就业人口变动(三月)             273K      -124K
3   20200403  20:30      美国  美国季调后非农就业人口变动(三月)             273K      -100K
4   20200403  20:30      美国  美国季调后非农就业人口变动(三月)             273K      -123K
..       ...    ...     ...                ...    ...       ...        ...
95  20190308  21:30      美国  美国季调后非农就业人口变动(二月)             304K       181K
96  20190308  21:30      美国  美国季调后非农就业人口变动(二月)             304K       180K
97  20190308  21:30      美国  美国季调后非农就业人口变动(二月)             304K       185K
98  20190308  21:30      美国  美国季调后非农就业人口变动(二月)             304K       180K
99  20190308  21:30      美国  美国季调后非农就业人口变动(二月)             304K       185K
```